/* -*- c++ -*- */
/*
 * Copyright 2006,2009,2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 */

#if HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdlib.h>
#include <gnuradio/constants.h>

namespace gr {

  const std::string
  prefix()
  {
    //Use "GR_PREFIX" environment variable when specified
    const char *prefix = getenv("GR_PREFIX");
    if (prefix != NULL) return prefix;

    return "/usr";
  }

  const std::string
  sysconfdir()
  {
    //Provide the sysconfdir in terms of prefix()
    //when the "GR_PREFIX" environment var is specified.
    if (getenv("GR_PREFIX") != NULL)
    {
      return prefix() + "/etc";
    }

    return "/etc";
  }

  const std::string
  prefsdir()
  {
    //Provide the prefsdir in terms of sysconfdir()
    //when the "GR_PREFIX" environment var is specified.
    if (getenv("GR_PREFIX") != NULL)
    {
      return sysconfdir() + "/gnuradio/conf.d";
    }

    return "/etc/gnuradio/conf.d";
  }

  const std::string
  build_date()
  {
    return "Wed, 17 Feb 2021 00:00:00";
  }

  const std::string
  version()
  {
    return "3.9.0.0";
  }

  // Return individual parts of the version
  const std::string
  major_version()
  {
    return "3";
  }

  const std::string
  api_version()
  {
    return "9";
  }

  const std::string
  minor_version()
  {
    return "0";
  }

  const std::string
  c_compiler()
  {
    return "gcc (GCC) 11.0.0 20210210 (Red Hat 11.0.0-0) \nCopyright (C) 2021 Free Software Foundation, Inc. \nThis is free software see the source for copying conditions.  There is NO \nwarranty not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.";
  }

  const std::string
  cxx_compiler()
  {
    return "g++ (GCC) 11.0.0 20210210 (Red Hat 11.0.0-0) \nCopyright (C) 2021 Free Software Foundation, Inc. \nThis is free software see the source for copying conditions.  There is NO \nwarranty not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.";
  }

  const std::string
  compiler_flags()
  {
    return "/usr/bin/gcc:::-DNDEBUG -O2 -flto=auto -ffat-lto-objects -fexceptions -g -grecord-gcc-switches -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS -specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 -fstack-protector-strong -specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 -march=zEC12 -mtune=z13 -fasynchronous-unwind-tables -fstack-clash-protection -fvisibility=hidden -Wsign-compare -Wno-uninitialized \n/usr/bin/g++:::-DNDEBUG -O2 -flto=auto -ffat-lto-objects -fexceptions -g -grecord-gcc-switches -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS -specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 -fstack-protector-strong -specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 -march=zEC12 -mtune=z13 -fasynchronous-unwind-tables -fstack-clash-protection -fvisibility=hidden -Wsign-compare -Wno-uninitialized";
  }

  const std::string
  build_time_enabled_components()
  {
    return "testing-support;python-support;post-install;doxygen;gnuradio-runtime;gr-ctrlport";
  }
} /* namespace gr */
